Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/browser.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/browser.py	(revision 8261)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/browser.py	(revision 8262)
@@ -544,5 +544,5 @@
     """
     grok.context(IApplicantOnlinePayment)
-    grok.name('payment_receipt.pdf')
+    grok.name('payment_slip.pdf')
     grok.require('waeup.viewApplication')
     form_fields = grok.AutoFields(IApplicantOnlinePayment)
@@ -561,17 +561,17 @@
     def label(self):
         portal_language = getUtility(IKofaUtils).PORTAL_LANGUAGE
-        return translate(_('Online Payment Receipt'),
+        return translate(_('Online Payment Slip'),
             'waeup.kofa', target_language=portal_language) \
             + ' %s' % self.context.p_id
 
     def render(self):
-        if self.context.p_state != 'paid':
-            self.flash(_('Ticket not yet paid.'))
-            self.redirect(self.url(self.context))
-            return
+        #if self.context.p_state != 'paid':
+        #    self.flash(_('Ticket not yet paid.'))
+        #    self.redirect(self.url(self.context))
+        #    return
         applicantview = ApplicantBaseDisplayFormPage(self.context.__parent__,
             self.request)
         students_utils = getUtility(IStudentsUtils)
-        return students_utils.renderPDF(self,'payment_receipt.pdf',
+        return students_utils.renderPDF(self,'payment_slip.pdf',
             self.context.__parent__, applicantview, note=self.note)
 
Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/viewlets.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/viewlets.py	(revision 8261)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/viewlets.py	(revision 8262)
@@ -166,11 +166,11 @@
     grok.require('waeup.viewApplication')
     icon = 'actionicon_pdf.png'
-    text = _('Download payment receipt')
-    target = 'payment_receipt.pdf'
+    text = _('Download payment slip')
+    target = 'payment_slip.pdf'
 
     @property
     def target_url(self):
-        if self.context.p_state != 'paid':
-            return ''
+        #if self.context.p_state != 'paid':
+        #    return ''
         return self.view.url(self.view.context, self.target)
 
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/browser.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/browser.py	(revision 8261)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/browser.py	(revision 8262)
@@ -1184,5 +1184,5 @@
     """
     grok.context(IStudentOnlinePayment)
-    grok.name('payment_receipt.pdf')
+    grok.name('payment_slip.pdf')
     grok.require('waeup.viewStudent')
     form_fields = grok.AutoFields(IStudentOnlinePayment)
@@ -1190,20 +1190,28 @@
     form_fields['payment_date'].custom_widget = FriendlyDatetimeDisplayWidget('le')
     prefix = 'form'
-    title = 'Payment Data'
     note = None
 
     @property
+    def title(self):
+        portal_language = getUtility(IKofaUtils).PORTAL_LANGUAGE
+        return translate(_('Payment Data'), 'waeup.kofa',
+            target_language=portal_language)
+
+    @property
     def label(self):
-        return 'Online Payment Receipt %s' % self.context.p_id
+        portal_language = getUtility(IKofaUtils).PORTAL_LANGUAGE
+        return translate(_('Online Payment Slip'),
+            'waeup.kofa', target_language=portal_language) \
+            + ' %s' % self.context.p_id
 
     def render(self):
-        if self.context.p_state != 'paid':
-            self.flash('Ticket not yet paid.')
-            self.redirect(self.url(self.context))
-            return
+        #if self.context.p_state != 'paid':
+        #    self.flash('Ticket not yet paid.')
+        #    self.redirect(self.url(self.context))
+        #    return
         studentview = StudentBaseDisplayFormPage(self.context.getStudent(),
             self.request)
         students_utils = getUtility(IStudentsUtils)
-        return students_utils.renderPDF(self, 'payment_receipt.pdf',
+        return students_utils.renderPDF(self, 'payment_slip.pdf',
             self.context.getStudent(), studentview, note=self.note)
 
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/viewlets.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/viewlets.py	(revision 8261)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/viewlets.py	(revision 8262)
@@ -319,11 +319,11 @@
     grok.require('waeup.viewStudent')
     icon = 'actionicon_pdf.png'
-    text = _('Download payment receipt')
-    target = 'payment_receipt.pdf'
-
-    @property
-    def target_url(self):
-        if self.context.p_state != 'paid':
-            return ''
+    text = _('Download payment slip')
+    target = 'payment_slip.pdf'
+
+    @property
+    def target_url(self):
+        #if self.context.p_state != 'paid':
+        #    return ''
         return self.view.url(self.view.context, self.target)
 

Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_browser.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_browser.py	(revision 8261)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_browser.py	(revision 8262)
@@ -635,8 +635,8 @@
                            self.browser.contents)
         payment_url = self.browser.url
-        # The pdf payment receipt can't yet be opened
-        self.browser.open(payment_url + '/payment_receipt.pdf')
-        self.assertMatches('...Ticket not yet paid...',
-                           self.browser.contents)
+        # The pdf payment slip can't yet be opened
+        #self.browser.open(payment_url + '/payment_receipt.pdf')
+        #self.assertMatches('...Ticket not yet paid...',
+        #                   self.browser.contents)
         # Request callback
         self.browser.open(payment_url)
@@ -649,7 +649,7 @@
             "...Transition 'pay' requires 'started' as source state...",
             self.browser.contents)
         # The payment receipt can be downloaded now
         self.browser.open(payment_url)
-        self.browser.getLink("Download payment receipt").click()
+        self.browser.getLink("Download payment slip").click()
         self.assertEqual(self.browser.headers['Status'], '200 Ok')
         self.assertEqual(self.browser.headers['Content-Type'],
@@ -649,7 +649,7 @@
             "...Transition 'pay' requires 'started' as source state...",
             self.browser.contents)
-        # The payment receipt can be downloaded now
+        # The payment slip can be downloaded now
         self.browser.open(payment_url)
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/tests/test_browser.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/tests/test_browser.py	(revision 8261)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/tests/test_browser.py	(revision 8262)
@@ -1271,8 +1271,8 @@
         payment_url = self.browser.url
 
-        # The pdf payment receipt can't yet be opened
-        self.browser.open(payment_url + '/payment_receipt.pdf')
-        self.assertMatches('...Ticket not yet paid...',
-                           self.browser.contents)
+        # The pdf payment slip can't yet be opened
+        #self.browser.open(payment_url + '/payment_slip.pdf')
+        #self.assertMatches('...Ticket not yet paid...',
+        #                   self.browser.contents)
 
         # The same payment (with same p_item, p_session and p_category)
@@ -1307,7 +1307,7 @@
             self.browser.contents)
 
         # Managers can open the pdf payment receipt
         self.browser.open(payment_url)
-        self.browser.getLink("Download payment receipt").click()
+        self.browser.getLink("Download payment slip").click()
         self.assertEqual(self.browser.headers['Status'], '200 Ok')
         self.assertEqual(self.browser.headers['Content-Type'], 'application/pdf')
@@ -1384,6 +1384,6 @@
         ac.owner = self.student_id
 
-        # Students can open the pdf payment receipt
-        self.browser.open(payment_url + '/payment_receipt.pdf')
+        # Students can open the pdf payment slip
+        self.browser.open(payment_url + '/payment_slip.pdf')
         self.assertEqual(self.browser.headers['Status'], '200 Ok')
         self.assertEqual(self.browser.headers['Content-Type'], 'application/pdf')
@@ -1307,7 +1307,7 @@
             self.browser.contents)
 
-        # Managers can open the pdf payment receipt
+        # Managers can open the pdf payment slip
         self.browser.open(payment_url)